@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,4,5)
+VERSION = (0,4,6)
 VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
 
 VERSION_INFO = """
@@ -10,7 +10,8 @@ Version: %s
 Date: 21.07.2011
 
 Hints:
-- 0.4.5 -   Small adjustments in example project
+- 0.4.6 -   changes in setup.py to avoid to install the example project.
+- 0.4.5 -   Small adjustments at the example project.
 - 0.4.4 -   1. Because of incomplete setup.py the last distributed package
             does't contained temples and language files.
             2. Readme updated.
